==> eventum-3.5.1.tar.xz: eventum-3.5.1/src/EventDispatcher/EventManager.php <==
<?php

/*
 * This file is part of the Eventum (Issue Tracking System) package.
 *
 * @copyright (c) Eventum Team
 * @license GNU General Public License, version 2 or later (GPL-2+)
 *
 * For the full copyright and license information,
 * please see the COPYING and AUTHORS files
 * that were distributed with this source code.
 */

namespace Eventum\EventDispatcher;

use Eventum\Event\MailQueueListener;
use Eventum\Extension\ExtensionManager;
use Symfony\Component\EventDispatcher\Event;
use Symfony\Component\EventDispatcher\EventDispatcher;

class EventManager
{
    /**
     * Singleton for Event Dispatcher
     *
     * @return EventDispatcher
     */
    public static function getEventDispatcher()
    {
        static $dispatcher;
        if (!$dispatcher) {
            $dispatcher = new EventDispatcher();

            // register subscribers from extensions
            $em = ExtensionManager::getManager();
            $subscribers = $em->getSubscribers();
            foreach ($subscribers as $subscriber) {
                $dispatcher->addSubscriber($subscriber);
            }

            // load builtin even subscribers
            $dispatcher->addSubscriber(new MailQueueListener());
        }

        return $dispatcher;
    }

    /**
     * Helper to dispatch events
     *
     * @param string $eventName
     * @param Event $event
     * @return Event
     * @see EventDispatcherInterface::dispatch()
     */
    public static function dispatch($eventName, Event $event = null)
    {
        return self::getEventDispatcher()->dispatch($eventName, $event);
    }
}

==> eventum-3.6.4.tar.xz: eventum-3.6.4/src/EventDispatcher/EventManager.php <==
<?php

/*
 * This file is part of the Eventum (Issue Tracking System) package.
 *
 * @copyright (c) Eventum Team
 * @license GNU General Public License, version 2 or later (GPL-2+)
 *
 * For the full copyright and license information,
 * please see the COPYING and AUTHORS files
 * that were distributed with this source code.
 */

namespace Eventum\EventDispatcher;

use Eventum\Event\Subscriber\MailQueueListener;
use Eventum\Extension\ExtensionManager;
use Symfony\Component\EventDispatcher\Event;
use Symfony\Component\EventDispatcher\EventDispatcher;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

class EventManager
{
    /**
     * Singleton for Event Dispatcher
     */
    public static function getEventDispatcher(): EventDispatcherInterface
    {
        static $dispatcher;
        if (!$dispatcher) {
            $dispatcher = new EventDispatcher();

            // register subscribers from extensions
            $em = ExtensionManager::getManager();
            $subscribers = $em->getSubscribers();
            foreach ($subscribers as $subscriber) {
                $dispatcher->addSubscriber($subscriber);
            }

            // load builtin even subscribers
            $dispatcher->addSubscriber(new MailQueueListener());
        }

        return $dispatcher;
    }

    /**
     * Helper to dispatch events
     *
     * @param string $eventName
     * @param Event $event
     * @return Event
     * @see EventDispatcherInterface::dispatch()
     */
    public static function dispatch($eventName, Event $event = null): Event
    {
        return self::getEventDispatcher()->dispatch($eventName, $event);
    }
}
